@@ -4,7 +4,7 @@ import pytest
 
 from testapp.models import User, Profile, Thread, Message, Tagged, Bookmark, Item
 
-from pydantic_django import PydanticDjangoModel
+from pydantic_django import ModelSchema
 
 
 @pytest.mark.django_db
@@ -13,7 +13,7 @@ def test_query_create():
     Test creating and saving a Django object to populate the schema model.
     """
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "email"]
@@ -56,7 +56,7 @@ def test_get_instance():
         first_name="Jordan", last_name="Eremieff", email="jordan@eremieff.com"
     )
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "first_name"]
@@ -76,11 +76,11 @@ def test_get_instance_with_generic_foreign_key():
     bookmark = Bookmark.objects.create(url="https://www.djangoproject.com/")
     Tagged.objects.create(content_object=bookmark, slug="django")
 
-    class TaggedSchema(PydanticDjangoModel):
+    class TaggedSchema(ModelSchema):
         class Config:
             model = Tagged
 
-    class BookmarkWithTaggedSchema(PydanticDjangoModel):
+    class BookmarkWithTaggedSchema(ModelSchema):
 
         tags: List[TaggedSchema]
 
@@ -105,7 +105,7 @@ def test_save_instance():
         first_name="Jordan", last_name="Eremieff", email="jordan@eremieff.com"
     )
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "first_name", "last_name"]
@@ -133,7 +133,7 @@ def test_refresh_instance():
         first_name="Jordan", last_name="Eremieff", email="jordan@eremieff.com"
     )
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "email", "profile"]
@@ -167,7 +167,7 @@ def test_delete_instance():
         first_name="Jordan", last_name="Eremieff", email="jordan@eremieff.com"
     )
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
 
@@ -191,7 +191,7 @@ def test_get_queryset_with_reverse_one_to_one():
         user = User.objects.create(**kwargs)
         Profile.objects.create(user=user, location="Australia")
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "email", "first_name", "profile"]
@@ -211,12 +211,12 @@ def test_get_queryset_with_reverse_one_to_one():
     }
 
     # Test when using a declared sub-model
-    class ProfileSchema(PydanticDjangoModel):
+    class ProfileSchema(ModelSchema):
         class Config:
             model = Profile
             include = ["id", "location"]
 
-    class UserWithProfileSchema(PydanticDjangoModel):
+    class UserWithProfileSchema(ModelSchema):
 
         profile: ProfileSchema
 
@@ -245,6 +245,50 @@ def test_get_queryset_with_reverse_one_to_one():
     }
 
 
+@pytest.mark.django_db
+def test_get_queryset_with_foreign_key():
+    """
+    Test retrieving a Django queryset with foreign-key relationships.
+    """
+
+    thread = Thread.objects.create(title="My thread topic")
+    thread2 = Thread.objects.create(title="Another topic")
+    for content in ("I agree.", "I disagree!", "lol"):
+        message_one = Message.objects.create(content=content, thread=thread)
+        Message.objects.create(content=content, thread=thread2)
+
+    class MessageSchema(ModelSchema):
+        class Config:
+            model = Message
+            exclude = ["created_at"]
+
+    schema = MessageSchema.from_django(message_one)
+    assert schema.dict() == {"id": 5, "content": "lol", "thread": 1}
+
+    class ThreadSchema(ModelSchema):
+        class Config:
+            model = Thread
+            exclude = ["created_at"]
+
+    class MessageWithThreadSchema(ModelSchema):
+        thread: ThreadSchema
+
+        class Config:
+            model = Message
+            exclude = ["created_at"]
+
+    schema = MessageWithThreadSchema.from_django(message_one)
+    assert schema.dict() == {
+        "id": 5,
+        "content": "lol",
+        "thread": {
+            "messages": [{"id": 1}, {"id": 3}, {"id": 5}],
+            "id": 1,
+            "title": "My thread topic",
+        },
+    }
+
+
 @pytest.mark.django_db
 def test_get_queryset_with_reverse_foreign_key():
     """
@@ -259,12 +303,12 @@ def test_get_queryset_with_reverse_foreign_key():
 
     threads = Thread.objects.all()
 
-    class MessageSchema(PydanticDjangoModel):
+    class MessageSchema(ModelSchema):
         class Config:
             model = Message
             include = ["id", "content"]
 
-    class ThreadSchema(PydanticDjangoModel):
+    class ThreadSchema(ModelSchema):
         class Config:
             model = Thread
 
@@ -285,7 +329,7 @@ def test_get_queryset_with_reverse_foreign_key():
     }
 
     # Test when using a declared sub-model
-    class ThreadWithMessageListSchema(PydanticDjangoModel):
+    class ThreadWithMessageListSchema(ModelSchema):
         messages: List[MessageSchema]
 
         class Config:
@@ -318,3 +362,26 @@ def test_get_queryset_with_reverse_foreign_key():
             },
         ]
     }
+
+
+@pytest.mark.django_db
+def test_get_queryset_with_generic_foreign_key():
+
+    bookmark = Bookmark.objects.create(url="https://github.com")
+    bookmark.tags.create(slug="tag-1")
+    bookmark.tags.create(slug="tag-2")
+
+    class TaggedSchema(ModelSchema):
+        class Config:
+            model = Tagged
+
+    class BookmarkSchema(ModelSchema):
+        class Config:
+            model = Bookmark
+
+    schema = BookmarkSchema.from_django(bookmark)
+    schema.dict() == {
+        "id": 1,
+        "url": "https://github.com",
+        "tags": [{"pk": 1}, {"pk": 2}],
+    }
