@@ -1,4 +1,5 @@
-from typing import List
+import datetime
+from typing import List, Dict
 
 import pytest
 
@@ -15,7 +16,7 @@ from testapp.models import (
     Bookmark,
 )
 
-from pydantic_django import PydanticDjangoModel
+from pydantic_django import ModelSchema
 
 
 @pytest.mark.django_db
@@ -24,7 +25,7 @@ def test_m2m():
     Test forward m2m relationships.
     """
 
-    class ArticleSchema(PydanticDjangoModel):
+    class ArticleSchema(ModelSchema):
         class Config:
             model = Article
 
@@ -48,12 +49,11 @@ def test_m2m():
         "required": ["headline", "pub_date", "publications"],
     }
 
-    class PublicationSchema(PydanticDjangoModel):
+    class PublicationSchema(ModelSchema):
         class Config:
             model = Publication
 
-    class ArticleWithPublicationListSchema(PydanticDjangoModel):
-
+    class ArticleWithPublicationListSchema(ModelSchema):
         publications: List[PublicationSchema]
 
         class Config:
@@ -96,6 +96,20 @@ def test_m2m():
         },
     }
 
+    article = Article.objects.create(
+        headline="My Headline", pub_date=datetime.date(2021, 3, 20)
+    )
+    publication = Publication.objects.create(title="My Publication")
+    article.publications.add(publication)
+
+    schema = ArticleWithPublicationListSchema.from_django(article)
+    assert schema.dict() == {
+        "id": 1,
+        "headline": "My Headline",
+        "pub_date": datetime.date(2021, 3, 20),
+        "publications": [{"article": 1, "id": 1, "title": "My Publication"}],
+    }
+
 
 @pytest.mark.django_db
 def test_foreign_key():
@@ -103,11 +117,11 @@ def test_foreign_key():
     Test forward foreign-key relationships.
     """
 
-    class ThreadSchema(PydanticDjangoModel):
+    class ThreadSchema(ModelSchema):
         class Config:
             model = Thread
 
-    class MessageSchema(PydanticDjangoModel):
+    class MessageSchema(ModelSchema):
         class Config:
             model = Message
 
@@ -128,7 +142,7 @@ def test_foreign_key():
         "required": ["content", "created_at", "thread"],
     }
 
-    class MessageWithThreadSchema(PydanticDjangoModel):
+    class MessageWithThreadSchema(ModelSchema):
 
         thread: ThreadSchema
 
@@ -179,11 +193,11 @@ def test_foreign_key_reverse():
     Test reverse foreign-key relationships.
     """
 
-    class MessageSchema(PydanticDjangoModel):
+    class MessageSchema(ModelSchema):
         class Config:
             model = Message
 
-    class ThreadSchema(PydanticDjangoModel):
+    class ThreadSchema(ModelSchema):
         class Config:
             model = Thread
 
@@ -206,7 +220,7 @@ def test_foreign_key_reverse():
         "required": ["title"],
     }
 
-    class ThreadWithMessageListSchema(PydanticDjangoModel):
+    class ThreadWithMessageListSchema(ModelSchema):
         messages: List[MessageSchema]
 
         class Config:
@@ -253,11 +267,11 @@ def test_one_to_one():
     Test forward one-to-one relationships.
     """
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
 
-    class ProfileSchema(PydanticDjangoModel):
+    class ProfileSchema(ModelSchema):
         class Config:
             model = Profile
 
@@ -284,7 +298,7 @@ def test_one_to_one():
         "required": ["user"],
     }
 
-    class ProfileWithUserSchema(PydanticDjangoModel):
+    class ProfileWithUserSchema(ModelSchema):
         user: UserSchema
 
         class Config:
@@ -353,11 +367,11 @@ def test_one_to_one_reverse():
     Test reverse one-to-one relationships.
     """
 
-    class ProfileSchema(PydanticDjangoModel):
+    class ProfileSchema(ModelSchema):
         class Config:
             model = Profile
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
 
@@ -384,7 +398,7 @@ def test_one_to_one_reverse():
         "required": ["user"],
     }
 
-    class UserWithProfileSchema(PydanticDjangoModel):
+    class UserWithProfileSchema(ModelSchema):
         profile: ProfileSchema
 
         class Config:
@@ -445,7 +459,7 @@ def test_generic_relation():
     Test generic foreign-key relationships.
     """
 
-    class TaggedSchema(PydanticDjangoModel):
+    class TaggedSchema(ModelSchema):
         class Config:
             model = Tagged
 
@@ -463,7 +477,11 @@ def test_generic_relation():
         "required": ["slug", "content_type", "object_id", "content_object"],
     }
 
-    class BookmarkSchema(PydanticDjangoModel):
+    class BookmarkSchema(ModelSchema):
+        # FIXME: I added this because for some reason in 2.2 the GenericRelation field
+        # ends up required, but in 3 it does not.
+        tags: List[Dict[str, int]] = None
+
         class Config:
             model = Bookmark
 
@@ -483,10 +501,10 @@ def test_generic_relation():
                 },
             },
         },
-        "required": ["url", "tags"],
+        "required": ["url"],
     }
 
-    class BookmarkWithTaggedSchema(PydanticDjangoModel):
+    class BookmarkWithTaggedSchema(ModelSchema):
 
         tags: List[TaggedSchema]
 
@@ -524,7 +542,7 @@ def test_generic_relation():
         },
     }
 
-    class ItemSchema(PydanticDjangoModel):
+    class ItemSchema(ModelSchema):
 
         tags: List[TaggedSchema]
 
