@@ -4,9 +4,9 @@ from typing import Optional
 import pytest
 from pydantic import BaseModel, Field
 
-from testapp.models import User, Profile, RequestLog
+from testapp.models import User, Profile, Configuration
 
-from pydantic_django import PydanticDjangoModel
+from pydantic_django import ModelSchema
 
 
 @pytest.mark.django_db
@@ -15,7 +15,7 @@ def test_description():
     Test setting the schema description to the docstring of the Pydantic model.
     """
 
-    class ProfileSchema(PydanticDjangoModel):
+    class ProfileSchema(ModelSchema):
         """
         Pydantic profile docstring.
         """
@@ -25,7 +25,7 @@ def test_description():
 
     assert ProfileSchema.schema()["description"] == "Pydantic profile docstring."
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Pydantic user docstring.
         """
@@ -36,7 +36,7 @@ def test_description():
     assert UserSchema.schema()["description"] == "Pydantic user docstring."
 
     # Default will be the model docstring
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
 
@@ -49,7 +49,7 @@ def test_cache():
     Test the schema cache.
     """
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         class Config:
             model = User
             include = ["id", "first_name"]
@@ -68,8 +68,7 @@ def test_cache():
     assert True not in UserSchema.__schema_cache__
     assert False not in UserSchema.__schema_cache__
     assert UserSchema.schema() == expected
-    assert True in UserSchema.__schema_cache__
-    assert False not in UserSchema.__schema_cache__
+    assert UserSchema.__schema_cache__.keys() == {(True, "#/definitions/{model}")}
     assert UserSchema.schema() == expected
 
 
@@ -81,7 +80,7 @@ def test_include_exclude():
 
     all_user_fields = [field.name for field in User._meta.get_fields()]
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         All fields are included by default.
         """
@@ -91,7 +90,7 @@ def test_include_exclude():
 
     assert set(UserSchema.schema()["properties"].keys()) == set(all_user_fields)
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         All fields are included explicitly.
         """
@@ -101,7 +100,7 @@ def test_include_exclude():
 
     assert set(UserSchema.schema()["properties"].keys()) == set(all_user_fields)
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Only 'first_name' and 'email' are included.
         """
@@ -116,7 +115,7 @@ def test_include_exclude():
     assert set(included) == set(UserSchema.__config__.include)
     assert set(included) == set(["first_name", "email"])
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Only 'id' and 'profile' are not excluded.
         """
@@ -145,7 +144,7 @@ def test_annotations():
     Test annotating fields.
     """
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Test required, optional, and function fields.
 
@@ -164,7 +163,7 @@ def test_annotations():
 
     updated_at_dt = datetime.datetime(2020, 12, 31, 0, 0)
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Test field functions and factory defaults.
         """
@@ -189,7 +188,7 @@ def test_annotations():
 
 
 def test_by_alias_generator():
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         """
         Test alias generator.
         """
@@ -232,7 +231,7 @@ def test_sub_model():
 
         referral_code: Optional[str]
 
-    class ProfileSchema(PydanticDjangoModel):
+    class ProfileSchema(ModelSchema):
         """
         Django model relation as a sub-model.
         """
@@ -241,7 +240,7 @@ def test_sub_model():
             model = Profile
             include = ["id"]
 
-    class UserSchema(PydanticDjangoModel):
+    class UserSchema(ModelSchema):
         sign_up: SignUp
         profile: ProfileSchema
 
@@ -272,16 +271,16 @@ def test_sub_model():
 
 @pytest.mark.django_db
 def test_json():
-    class RequestLogSchema(PydanticDjangoModel):
+    class ConfigurationSchema(ModelSchema):
         """
         Test JSON schema.
         """
 
         class Config:
-            model = RequestLog
+            model = Configuration
 
     expected = """{
-  "title": "RequestLogSchema",
+  "title": "ConfigurationSchema",
   "description": "Test JSON schema.",
   "type": "object",
   "properties": {
@@ -289,31 +288,48 @@ def test_json():
       "title": "Id",
       "type": "integer"
     },
-    "request_id": {
-      "title": "Request Id",
-      "description": "Unique id of the request.",
+    "config_id": {
+      "title": "Config Id",
+      "description": "Unique id of the configuration.",
       "type": "string",
       "format": "uuid"
     },
-    "response_time": {
-      "title": "Response Time",
-      "type": "number",
-      "format": "time-delta"
+    "name": {
+      "title": "Name",
+      "maxLength": 100,
+      "type": "string"
     },
-    "ip_address": {
-      "title": "Ip Address",
-      "type": "string",
-      "format": "ipvanyaddress"
+    "permissions": {
+      "title": "Permissions",
+      "anyOf": [
+        {
+          "type": "string",
+          "format": "json-string"
+        },
+        {
+          "type": "object"
+        },
+        {
+          "type": "array",
+          "items": {}
+        }
+      ]
     },
-    "host_ipv4_address": {
-      "title": "Host Ipv4 Address",
-      "type": "string",
-      "format": "ipvanyaddress"
-    },
-    "host_ipv6_address": {
-      "title": "Host Ipv6 Address",
-      "type": "string",
-      "format": "ipvanyaddress"
+    "changelog": {
+      "title": "Changelog",
+      "anyOf": [
+        {
+          "type": "string",
+          "format": "json-string"
+        },
+        {
+          "type": "object"
+        },
+        {
+          "type": "array",
+          "items": {}
+        }
+      ]
     },
     "metadata": {
       "title": "Metadata",
@@ -330,11 +346,16 @@ def test_json():
           "items": {}
         }
       ]
+    },
+    "version": {
+      "title": "Version",
+      "default": "0.0.1",
+      "maxLength": 5,
+      "type": "string"
     }
   },
   "required": [
-    "response_time"
+    "name"
   ]
 }"""
-
-    assert RequestLogSchema.schema_json(indent=2) == expected
+    assert ConfigurationSchema.schema_json(indent=2) == expected
